# Deep Research Prompt

**Generated:** {{date}}
**Created by:** {{user_name}}
**Target Platform:** {{target_platform}}

---

## Research Prompt (Ready to Use)

### Research Question

{{research_topic}}

### Research Goal and Context

**Objective:** {{research_goal}}

**Context:**
{{research_persona}}

### Scope and Boundaries

**Temporal Scope:** {{temporal_scope}}

**Geographic Scope:** {{geographic_scope}}

**Thematic Focus:**
{{thematic_boundaries}}

### Information Requirements

**Types of Information Needed:**
{{information_types}}

**Preferred Sources:**
{{preferred_sources}}

### Output Structure

**Format:** {{output_format}}

**Required Sections:**
{{key_sections}}

**Depth Level:** {{depth_level}}

### Research Methodology

**Keywords and Technical Terms:**
{{research_keywords}}

**Special Requirements:**
{{special_requirements}}

**Validation Criteria:**
{{validation_criteria}}

### Follow-up Strategy

{{follow_up_strategy}}

---

## Complete Research Prompt (Copy and Paste)

```
{{deep_research_prompt}}
```

---

## Platform-Specific Usage Tips

{{platform_tips}}

---

## Research Execution Checklist

{{execution_checklist}}

---

## Metadata

**Workflow:** BMad Research Workflow - Deep Research Prompt Generator v2.0
**Generated:** {{date}}
**Research Type:** Deep Research Prompt
**Platform:** {{target_platform}}

---

_This research prompt was generated using the BMad Method Research Workflow, incorporating best practices from ChatGPT Deep Research, Gemini Deep Research, Grok DeepSearch, and Claude Projects (2025)._
